@@ -2,7 +2,7 @@
 from models import *
 
 from django.contrib.sites.models import Site
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -73,8 +73,6 @@ class CMSSatchmoCategoryPlugin(CMSPluginBase):
 	fields = ['category', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-#		category = Category.objects.get(id=instance.category_id)
-
 		context.update({
 			'instance': instance,
 			'placeholder': placeholder,
