@@ -9,6 +9,16 @@ from product.models import Product, Category
 
 
 
+RECENT_PRODUCTS_CHOICE_ID = 1
+BESTSELLERS_CHOICE_ID = 2
+FEATURED_PRODUCTS_CHOICE_ID = 3
+
+PRODUCTS_LISTING_CHOICES = (
+	(RECENT_PRODUCTS_CHOICE_ID, _(u'recent products'),),
+	(BESTSELLERS_CHOICE_ID, _(u'bestsellers'),),
+	(FEATURED_PRODUCTS_CHOICE_ID, _(u'featured products'),),
+)
+
 class SatchmoSiteSetting(models.Model):
 	"""Because every Satchmo site can use different settings for SHOP_BASE, PRODUCT_SLUG and CATEGORY_SLUG
 	the system must know the right variables for every site otherwise we can't create the right 'absolute_url'
@@ -42,11 +52,11 @@ class SatchmoSiteSetting(models.Model):
 		return '%s%s%s/%s%s/' % (site_url, self.shop_base, self.category_slug, slug_list, category.slug)
 
 	def product_url_path(self):
-		return '%s%s/<' % (self.shop_base, self.product_slug) +_('product')+'>'
+		return u'%s%s/<%s>' % (self.shop_base, self.product_slug, _(u'product'))
 	product_url_path.short_description = _(u'product\'s path')
 
 	def category_url_path(self):
-		return '%s%s/<' % (self.shop_base, self.category_slug) +_('category')+'>'
+		return u'%s%s/<%s>' % (self.shop_base, self.category_slug, _(u'category'))
 	category_url_path.short_description = _(u'category\'s path')
 
 	class Meta:
@@ -55,7 +65,7 @@ class SatchmoSiteSetting(models.Model):
 	
 
 
-class MyCMSPlugin(CMSPlugin):
+class CommonSatchmoPlugin(CMSPlugin):
 	"""Only wrapper for DRY reasons"""
 	title = models.CharField(_(u'title'), max_length=200, blank=True, help_text=_(u'Alternative text'))
 	style = models.CharField(_(u'class'), max_length=100, blank=True, help_text=_(u'Name of CSS class for template cusomization'))
@@ -65,7 +75,7 @@ class MyCMSPlugin(CMSPlugin):
 
 
 
-class SatchmoProductPlugin(MyCMSPlugin):
+class SatchmoProductPlugin(CommonSatchmoPlugin):
 	"""Model for the plugin for inlining a satchmo product"""
 	product = models.ForeignKey(Product, verbose_name=_(u'product'), limit_choices_to={'active': True})
 
@@ -75,17 +85,7 @@ class SatchmoProductPlugin(MyCMSPlugin):
 
 
 
-RECENT_PRODUCTS_CHOICE_ID = 1
-BESTSELLERS_CHOICE_ID = 2
-FEATURED_PRODUCTS_CHOICE_ID = 3
-
-PRODUCTS_LISTING_CHOICES = (
-	(RECENT_PRODUCTS_CHOICE_ID, _(u'recent products'),),
-	(BESTSELLERS_CHOICE_ID, _(u'bestsellers'),),
-	(FEATURED_PRODUCTS_CHOICE_ID, _(u'featured products'),),
-)
-
-class SatchmoProductsListPlugin(MyCMSPlugin):
+class SatchmoProductsListPlugin(CommonSatchmoPlugin):
 	"""Model for the plugin of product listing"""
 	list_type = models.PositiveSmallIntegerField(_(u'kind of list'), choices=PRODUCTS_LISTING_CHOICES)
 	number = models.PositiveSmallIntegerField(_(u'number'), default=5)
@@ -97,7 +97,7 @@ class SatchmoProductsListPlugin(MyCMSPlugin):
 
 
 
-class SatchmoCategoryPlugin(MyCMSPlugin):
+class SatchmoCategoryPlugin(CommonSatchmoPlugin):
 	"""Model for the plugin of category detail"""
 	category = models.ForeignKey(Category, verbose_name=_(u'category'), limit_choices_to={'is_active': True})
 
@@ -107,7 +107,7 @@ class SatchmoCategoryPlugin(MyCMSPlugin):
 
 
 
-class SatchmoCategoriesListPlugin(MyCMSPlugin):
+class SatchmoCategoriesListPlugin(CommonSatchmoPlugin):
 	main_category = models.ForeignKey(Category, verbose_name=_(u'main category'), limit_choices_to={'is_active': True}, blank=True, null=True,
 		help_text=_(u'Leave blank for listing root categories or select main category for listing their child categries.')
 	)
